# wkmake
Some simple python project build tools.

# Install
`pip3 install wkmake`

# Usage
```shell script
# quick start
wkmake make cfg.json
# comstomize
wkmake make --src=python_pacakge --dst='./output' --cfg=cfg.json 
```
Check out the result in folder `demo`